@@ -1,8 +1,9 @@
 mod build;
-pub mod common;
+mod common;
 mod run;
 mod test;
 
 pub use build::Build;
+pub use common::XWinOptions;
 pub use run::Run;
 pub use test::Test;
